@@ -1,3 +1,5 @@
+import sys
+
 import re
 import statistics
 
@@ -17,6 +19,8 @@ def chat_with(bot, user_name="You", logger=None):
         logger.info(f'{user_name} :')
         # 3) ask for input
         user_input = input()
+        sys.stdout.write('\n')
+        sys.stdout.flush()
 
         response = bot.respond_to(user_input)
 
@@ -223,7 +227,7 @@ class SimpleBot(Base):
 
     def _log_response(self, actor_name, response, score=None):
         if score is not None:
-            self._log.info('%s [%f] : \n%s' % (actor_name, score, response))
+            self._log.info('%s [%f] : \n%s\n' % (actor_name, score, response))
         else:
-            self._log.info('%s : \n%s' % (actor_name, response))
+            self._log.info('%s : \n%s\n' % (actor_name, response))
 
